@@ -29,8 +29,8 @@
 #include <tqcursor.h>
 #include <tqmap.h>
 
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
 #include "kiledebug.h"
 
 namespace KileDialog 
@@ -1832,7 +1832,7 @@ TabularCell::Count TabularTable::countCells(int x1,int y1,int x2,int y2)
 
 //BEGIN TabularDialog
 
-TabularDialog::TabularDialog(TQWidget *parent, KConfig *config, KileDocument::LatexCommands *commands, bool tabularenv) 
+TabularDialog::TabularDialog(TQWidget *parent, TDEConfig *config, KileDocument::LatexCommands *commands, bool tabularenv) 
 	: Wizard(config,parent), m_latexCommands(commands)
 {
 	TQWidget *page = new TQWidget(this);
